summaryrefslogtreecommitdiff
path: root/tests/helpers/fixtures.py
diff options
context:
space:
mode:
authorFlorian Bruhin <me@the-compiler.org>2020-01-10 19:53:01 +0100
committerFlorian Bruhin <me@the-compiler.org>2020-01-10 21:51:18 +0100
commit6cceadd9a79a83c5c351d633e486149af1746cbc (patch)
tree413653bd94f0fa8f3491f84b4e59f09c72fef43e /tests/helpers/fixtures.py
parent1239a1c704349a0b185d357434236f0156c03c7f (diff)
downloadqutebrowser-6cceadd9a79a83c5c351d633e486149af1746cbc.tar.gz
qutebrowser-6cceadd9a79a83c5c351d633e486149af1746cbc.zip
Replace fonts.monospace setting by rewritten fonts.default_families
This now is a list, which is empty by default. When empty, a system-specific default monospace font is used instead of hardcoding font families in the config. Doesn't fix #5184, although I thought it would. Fixes #3107
Diffstat (limited to 'tests/helpers/fixtures.py')
-rw-r--r--tests/helpers/fixtures.py5
1 files changed, 3 insertions, 2 deletions
diff --git a/tests/helpers/fixtures.py b/tests/helpers/fixtures.py
index bb33a8cfd..1215868f7 100644
--- a/tests/helpers/fixtures.py
+++ b/tests/helpers/fixtures.py
@@ -313,9 +313,10 @@ def config_stub(stubs, monkeypatch, configdata_init, yaml_config_stub):
monkeypatch.setattr(config, 'cache', cache)
try:
- configtypes.Font.monospace_fonts = container.fonts.monospace
+ configtypes.Font.set_default_family(['monospace'])
except configexc.NoOptionError:
# Completion tests patch configdata so fonts.monospace is unavailable.
pass
conf.val = container # For easier use in tests
@@ -313,9 +313,10 @@ def config_stub(stubs, monkeypatch, configdata_init, yaml_config_stub):
except configexc.NoOptionError:
- # Completion tests patch configdata so fonts.monospace is unavailable.
+ # Completion tests patch configdata so fonts.default_family is
+ # unavailable.
pass
conf.val = container # For easier use in tests